#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive
version:              0.9.1.0
visibility:           public
id:                   primitive-0.9.1.0-9QvFeV3W7tz7oFv7X4RERJ
key:                  primitive-0.9.1.0-9QvFeV3W7tz7oFv7X4RERJ
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  c04173070a7017e88360a963d6e15d44
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.PrimVar Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:
    Data.Primitive.Internal.Operations Data.Primitive.Internal.Read

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive
hs-libraries:         HSprimitive-0.9.1.0-9QvFeV3W7tz7oFv7X4RERJ
include-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0/include
depends:
    base-4.18.2.1 deepseq-1.4.8.1 template-haskell-2.20.0.0
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

